You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by hw...@apache.org on 2010/04/27 23:33:09 UTC

svn commit: r938674 - in /subversion/trunk/subversion: include/ include/private/ libsvn_client/ libsvn_wc/ svn/

Author: hwright
Date: Tue Apr 27 21:33:08 2010
New Revision: 938674

URL: http://svn.apache.org/viewvc?rev=938674&view=rev
Log:
Publicize a information-retrieving svn_wc__node_ function.  This function has
shown the need for widespread use, and is hereby promoted to public status.

* subversion/include/svn_wc.h
  (svn_wc_read_kind): New, moved from...

* subversion/include/private/svn_wc_private.h
  (svn_wc__node_get_kind): ...here.

* subversion/libsvn_wc/node.c
  (svn_wc__node_get_kind): Renamed to...
  (svn_wc_read_kind): ...this.

* subversion/svn/*
* subversion/libsvn_client/*
* subversion/libsvn_wc/*:
  Update callers.

Modified:
    subversion/trunk/subversion/include/private/svn_wc_private.h
    subversion/trunk/subversion/include/svn_wc.h
    subversion/trunk/subversion/libsvn_client/cat.c
    subversion/trunk/subversion/libsvn_client/changelist.c
    subversion/trunk/subversion/libsvn_client/cleanup.c
    subversion/trunk/subversion/libsvn_client/commit.c
    subversion/trunk/subversion/libsvn_client/copy.c
    subversion/trunk/subversion/libsvn_client/export.c
    subversion/trunk/subversion/libsvn_client/externals.c
    subversion/trunk/subversion/libsvn_client/info.c
    subversion/trunk/subversion/libsvn_client/merge.c
    subversion/trunk/subversion/libsvn_client/mergeinfo.c
    subversion/trunk/subversion/libsvn_client/patch.c
    subversion/trunk/subversion/libsvn_client/prop_commands.c
    subversion/trunk/subversion/libsvn_client/repos_diff.c
    subversion/trunk/subversion/libsvn_client/status.c
    subversion/trunk/subversion/libsvn_client/switch.c
    subversion/trunk/subversion/libsvn_client/update.c
    subversion/trunk/subversion/libsvn_wc/node.c
    subversion/trunk/subversion/libsvn_wc/status.c
    subversion/trunk/subversion/svn/main.c
    subversion/trunk/subversion/svn/propedit-cmd.c

Modified: subversion/trunk/subversion/include/private/svn_wc_private.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/private/svn_wc_private.h?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/include/private/svn_wc_private.h (original)
+++ subversion/trunk/subversion/include/private/svn_wc_private.h Tue Apr 27 21:33:08 2010
@@ -293,26 +293,6 @@ svn_wc__node_get_repos_info(const char *
                             apr_pool_t *scratch_pool);
 
 
-/**
- * Set @a kind to the @c svn_node_kind_t of @a abspath.  Use @a wc_ctx
- * to access the working copy, and @a scratch_pool for all temporary
- * allocations.
- *
- * If @a abspath is not under version control, set @a kind to @c svn_node_none.
- * If it is versioned but hidden and @a show_hidden is @c FALSE, also return @c
- * svn_node_none.
- *
- * If the node's info is incomplete, it may or may not have a known node kind
- * set. If the kind is not known (yet), set @a kind to @c svn_node_unknown.
- * Otherwise return the node kind even though the node is marked incomplete.
- */
-svn_error_t *
-svn_wc__node_get_kind(svn_node_kind_t *kind,
-                      svn_wc_context_t *wc_ctx,
-                      const char *abspath,
-                      svn_boolean_t show_hidden,
-                      apr_pool_t *scratch_pool);
-
 
 /**
  * Get the depth of @a local_abspath using @a wc_ctx.  If @a local_abspath is

Modified: subversion/trunk/subversion/include/svn_wc.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/include/svn_wc.h?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/include/svn_wc.h (original)
+++ subversion/trunk/subversion/include/svn_wc.h Tue Apr 27 21:33:08 2010
@@ -7585,6 +7585,29 @@ svn_wc_exclude(svn_wc_context_t *wc_ctx,
 
 /** @} */
 
+/**
+ * Set @a kind to the @c svn_node_kind_t of @a abspath.  Use @a wc_ctx
+ * to access the working copy, and @a scratch_pool for all temporary
+ * allocations.
+ *
+ * If @a abspath is not under version control, set @a kind to @c svn_node_none.
+ * If it is versioned but hidden and @a show_hidden is @c FALSE, also return @c
+ * svn_node_none.
+ *
+ * If the node's info is incomplete, it may or may not have a known node kind
+ * set. If the kind is not known (yet), set @a kind to @c svn_node_unknown.
+ * Otherwise return the node kind even though the node is marked incomplete.
+ *
+ * @since New in 1.7.
+ */
+svn_error_t *
+svn_wc_read_kind(svn_node_kind_t *kind,
+                 svn_wc_context_t *wc_ctx,
+                 const char *abspath,
+                 svn_boolean_t show_hidden,
+                 apr_pool_t *scratch_pool);
+
+
 /** @} */
 
 #ifdef __cplusplus

Modified: subversion/trunk/subversion/libsvn_client/cat.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/cat.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/cat.c (original)
+++ subversion/trunk/subversion/libsvn_client/cat.c Tue Apr 27 21:33:08 2010
@@ -68,8 +68,7 @@ cat_local_file(svn_wc_context_t *wc_ctx,
 
   SVN_ERR_ASSERT(SVN_CLIENT__REVKIND_IS_LOCAL_TO_WC(revision->kind));
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, wc_ctx, local_abspath, FALSE,
-                                scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&kind, wc_ctx, local_abspath, FALSE, scratch_pool));
 
   if (kind == svn_node_unknown || kind == svn_node_none)
     return svn_error_createf(SVN_ERR_UNVERSIONED_RESOURCE, NULL,

Modified: subversion/trunk/subversion/libsvn_client/changelist.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/changelist.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/changelist.c (original)
+++ subversion/trunk/subversion/libsvn_client/changelist.c Tue Apr 27 21:33:08 2010
@@ -66,8 +66,7 @@ set_node_changelist(const char *local_ab
                                  b->changelist_hash, pool))
     return SVN_NO_ERROR;
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, b->ctx->wc_ctx, local_abspath,
-                                FALSE, pool));
+  SVN_ERR(svn_wc_read_kind(&kind, b->ctx->wc_ctx, local_abspath, FALSE, pool));
 
   /* We only care about files right now. */
   if (kind != svn_node_file)
@@ -194,7 +193,7 @@ get_node_changelist(const char *local_ab
   svn_node_kind_t kind;
   const char *changelist;
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, b->wc_ctx, local_abspath, FALSE, pool));
+  SVN_ERR(svn_wc_read_kind(&kind, b->wc_ctx, local_abspath, FALSE, pool));
   SVN_ERR(svn_wc__node_get_changelist(&changelist, b->wc_ctx,
                                       local_abspath, pool, pool));
 

Modified: subversion/trunk/subversion/libsvn_client/cleanup.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/cleanup.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/cleanup.c (original)
+++ subversion/trunk/subversion/libsvn_client/cleanup.c Tue Apr 27 21:33:08 2010
@@ -177,8 +177,8 @@ svn_client_upgrade(const char *path,
              upgraded if it's a dir. If it's a file then the lookup is done
              in an adm_dir belonging to the real wc and since that was
              updated before the externals no error is returned. */
-          err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, external_abspath,
-                                        FALSE, iterpool);
+          err = svn_wc_read_kind(&kind, ctx->wc_ctx, external_abspath, FALSE,
+                                 iterpool);
 
           if (err && err->apr_err == SVN_ERR_WC_UPGRADE_REQUIRED)
             {

Modified: subversion/trunk/subversion/libsvn_client/commit.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/commit.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/commit.c (original)
+++ subversion/trunk/subversion/libsvn_client/commit.c Tue Apr 27 21:33:08 2010
@@ -992,8 +992,7 @@ check_nonrecursive_dir_delete(const char
 
   SVN_ERR(svn_dirent_get_absolute(&target_abspath, target_path, pool));
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, wc_ctx, target_abspath, FALSE,
-                                pool));
+  SVN_ERR(svn_wc_read_kind(&kind, wc_ctx, target_abspath, FALSE, pool));
   if (kind == svn_node_dir)
     lock_abspath = target_abspath;
   else

Modified: subversion/trunk/subversion/libsvn_client/copy.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/copy.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/copy.c (original)
+++ subversion/trunk/subversion/libsvn_client/copy.c Tue Apr 27 21:33:08 2010
@@ -1740,8 +1740,7 @@ repos_to_wc_copy(const apr_array_header_
     {
       svn_node_kind_t kind;
       top_src_url = svn_uri_dirname(top_src_url, pool);
-      SVN_ERR(svn_wc__node_get_kind(&kind, ctx->wc_ctx, top_dst_path, FALSE,
-                                    pool));
+      SVN_ERR(svn_wc_read_kind(&kind, ctx->wc_ctx, top_dst_path, FALSE, pool));
       if (kind != svn_node_dir)
         lock_abspath = svn_dirent_dirname(top_dst_path, pool);
     }

Modified: subversion/trunk/subversion/libsvn_client/export.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/export.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/export.c (original)
+++ subversion/trunk/subversion/libsvn_client/export.c Tue Apr 27 21:33:08 2010
@@ -344,8 +344,8 @@ copy_versioned_files(const char *from,
         return SVN_NO_ERROR;
     }
 
-  SVN_ERR(svn_wc__node_get_kind(&from_kind, ctx->wc_ctx, from_abspath,
-                                FALSE, pool));
+  SVN_ERR(svn_wc_read_kind(&from_kind, ctx->wc_ctx, from_abspath, FALSE,
+                           pool));
 
   if (from_kind == svn_node_dir)
     {
@@ -394,8 +394,8 @@ copy_versioned_files(const char *from,
           /* ### We could also invoke ctx->notify_func somewhere in
              ### here... Is it called for, though?  Not sure. */
 
-          SVN_ERR(svn_wc__node_get_kind(&child_kind, ctx->wc_ctx,
-                                        child_abspath, FALSE, iterpool));
+          SVN_ERR(svn_wc_read_kind(&child_kind, ctx->wc_ctx, child_abspath,
+                                   FALSE, iterpool));
 
           if (child_kind == svn_node_dir)
             {

Modified: subversion/trunk/subversion/libsvn_client/externals.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/externals.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/externals.c (original)
+++ subversion/trunk/subversion/libsvn_client/externals.c Tue Apr 27 21:33:08 2010
@@ -367,8 +367,7 @@ switch_file_external(const char *path,
                                          subpool, subpool));
     }
 
-  err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
-                              subpool);
+  err = svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE, subpool);
   if (err)
     goto cleanup;
 

Modified: subversion/trunk/subversion/libsvn_client/info.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/info.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/info.c (original)
+++ subversion/trunk/subversion/libsvn_client/info.c Tue Apr 27 21:33:08 2010
@@ -97,8 +97,7 @@ build_info_for_entry(svn_info_t **info,
                                       svn_node_unknown, TRUE, FALSE,
                                       pool, pool));
 
-  SVN_ERR(svn_wc__node_get_kind(&tmpinfo->kind, wc_ctx, local_abspath, TRUE,
-                                pool));
+  SVN_ERR(svn_wc_read_kind(&tmpinfo->kind, wc_ctx, local_abspath, TRUE, pool));
   SVN_ERR(svn_wc__node_get_url(&tmpinfo->URL, wc_ctx, local_abspath,
                                pool, pool));
   SVN_ERR(svn_wc__node_get_repos_info(&tmpinfo->repos_root_URL,

Modified: subversion/trunk/subversion/libsvn_client/merge.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/merge.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/merge.c (original)
+++ subversion/trunk/subversion/libsvn_client/merge.c Tue Apr 27 21:33:08 2010
@@ -437,8 +437,8 @@ obstructed_or_missing(const char *path,
   err = svn_dirent_get_absolute(&local_abspath, path, pool);
 
   if (!err)
-    err = svn_wc__node_get_kind(&wc_kind, merge_b->ctx->wc_ctx, local_abspath,
-                                FALSE, pool);
+    err = svn_wc_read_kind(&wc_kind, merge_b->ctx->wc_ctx, local_abspath,
+                           FALSE, pool);
 
   if (err)
     {
@@ -1378,8 +1378,8 @@ merge_file_changed(const char *local_dir
     svn_node_kind_t kind;
     svn_node_kind_t wc_kind;
 
-    SVN_ERR(svn_wc__node_get_kind(&wc_kind, merge_b->ctx->wc_ctx, mine_abspath,
-                                  FALSE, subpool));
+    SVN_ERR(svn_wc_read_kind(&wc_kind, merge_b->ctx->wc_ctx, mine_abspath,
+                             FALSE, subpool));
     SVN_ERR(svn_io_check_path(mine, &kind, subpool));
 
     /* ### a future thought:  if the file is under version control,
@@ -1762,8 +1762,8 @@ merge_file_added(const char *local_dir_a
         {
           /* directory already exists, is it under version control? */
           svn_node_kind_t wc_kind;
-          SVN_ERR(svn_wc__node_get_kind(&wc_kind, merge_b->ctx->wc_ctx,
-                                        mine_abspath, FALSE, subpool));
+          SVN_ERR(svn_wc_read_kind(&wc_kind, merge_b->ctx->wc_ctx,
+                                   mine_abspath, FALSE, subpool));
 
           if ((wc_kind != svn_node_none) && dry_run_deleted_p(merge_b, mine))
             *content_state = svn_wc_notify_state_changed;
@@ -4256,8 +4256,8 @@ calculate_merge_inheritance(apr_array_he
 {
   svn_node_kind_t path_kind;
 
-  SVN_ERR(svn_wc__node_get_kind(&path_kind, wc_ctx, local_abspath,
-                                FALSE, scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&path_kind, wc_ctx, local_abspath, FALSE,
+                           scratch_pool));
   if (path_kind == svn_node_file)
     {
       /* Files *never* have non-inheritable mergeinfo. */
@@ -5208,8 +5208,8 @@ get_mergeinfo_walk_cb(const char *local_
                                     scratch_pool));
     }
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, wb->ctx->wc_ctx,
-                                local_abspath, TRUE, scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&kind, wb->ctx->wc_ctx, local_abspath, TRUE,
+                           scratch_pool));
   SVN_ERR(svn_wc__node_get_depth(&depth, wb->ctx->wc_ctx, local_abspath,
                                  scratch_pool));
 
@@ -5406,9 +5406,9 @@ insert_parent_and_sibs_of_sw_absent_del_
             {
               svn_node_kind_t child_kind;
 
-              SVN_ERR(svn_wc__node_get_kind(&child_kind,
-                                            merge_cmd_baton->ctx->wc_ctx,
-                                            child_abspath, FALSE, iterpool));
+              SVN_ERR(svn_wc_read_kind(&child_kind,
+                                       merge_cmd_baton->ctx->wc_ctx,
+                                       child_abspath, FALSE, iterpool));
               if (child_kind != svn_node_file)
                 continue;
             }
@@ -5602,9 +5602,10 @@ get_mergeinfo_paths(apr_array_header_t *
                   if (depth == svn_depth_files)
                     {
                       svn_node_kind_t child_kind;
-                      SVN_ERR(svn_wc__node_get_kind(
-                        &child_kind, merge_cmd_baton->ctx->wc_ctx,
-                        child_abspath, FALSE, iterpool));
+                      SVN_ERR(svn_wc_read_kind(&child_kind,
+                                               merge_cmd_baton->ctx->wc_ctx,
+                                               child_abspath, FALSE,
+                                               iterpool));
                       if (child_kind != svn_node_file)
                         continue;
                     }
@@ -7134,10 +7135,8 @@ record_mergeinfo_for_added_subtrees(
           const char *rel_added_path;
           const char *added_path_mergeinfo_path;
 
-          SVN_ERR(svn_wc__node_get_kind(&added_path_kind,
-                                        merge_b->ctx->wc_ctx,
-                                        added_abspath, FALSE,
-                                        iterpool));
+          SVN_ERR(svn_wc_read_kind(&added_path_kind, merge_b->ctx->wc_ctx,
+                                   added_abspath, FALSE, iterpool));
 
           /* Calculate the mergeinfo resulting from this merge. */
           merge_mergeinfo = apr_hash_make(iterpool);
@@ -7978,8 +7977,8 @@ do_merge(apr_hash_t **modified_subtrees,
         return SVN_NO_ERROR;
     }
 
-  SVN_ERR(svn_wc__node_get_kind(&target_kind, ctx->wc_ctx, target_abspath,
-                                FALSE, pool));
+  SVN_ERR(svn_wc_read_kind(&target_kind, ctx->wc_ctx, target_abspath, FALSE,
+                           pool));
 
   /* Ensure a known depth. */
   if (depth == svn_depth_unknown)
@@ -8574,9 +8573,10 @@ get_target_and_lock_abspath(const char *
                             apr_pool_t *scratch_pool)
 {
   svn_node_kind_t kind;
-  SVN_ERR(svn_dirent_get_absolute(target_abspath, target_wcpath, scratch_pool));
-  SVN_ERR(svn_wc__node_get_kind(&kind, ctx->wc_ctx, *target_abspath, FALSE,
-                                scratch_pool));
+  SVN_ERR(svn_dirent_get_absolute(target_abspath, target_wcpath,
+                                  scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&kind, ctx->wc_ctx, *target_abspath, FALSE,
+                           scratch_pool));
   if (kind == svn_node_dir)
     *lock_abspath = *target_abspath;
   else

Modified: subversion/trunk/subversion/libsvn_client/mergeinfo.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/mergeinfo.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/mergeinfo.c (original)
+++ subversion/trunk/subversion/libsvn_client/mergeinfo.c Tue Apr 27 21:33:08 2010
@@ -417,8 +417,8 @@ svn_client__get_wc_mergeinfo_catalog(svn
 
   /* If LOCAL_ABSPATH is a directory and we want the subtree mergeinfo too,
      then get it. */
-  SVN_ERR(svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
-                                scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
+                           scratch_pool));
   if (kind == svn_node_dir && include_descendants)
     {
       wb.target_abspath = local_abspath;

Modified: subversion/trunk/subversion/libsvn_client/patch.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/patch.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/prop_commands.c (original)
+++ subversion/trunk/subversion/libsvn_client/prop_commands.c Tue Apr 27 21:33:08 2010
@@ -368,8 +368,7 @@ svn_client_propset3(svn_commit_info_t **
         SVN_ERR(svn_hash_from_cstring_keys(&changelist_hash,
                                            changelists, pool));
 
-      err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, target_abspath, FALSE,
-                                  pool);
+      err = svn_wc_read_kind(&kind, ctx->wc_ctx, target_abspath, FALSE, pool);
 
       if ((err && err->apr_err == SVN_ERR_WC_PATH_NOT_FOUND)
           || kind == svn_node_unknown || kind == svn_node_none)
@@ -861,8 +860,7 @@ svn_client_propget3(apr_hash_t **props,
 
       SVN_ERR(svn_dirent_get_absolute(&local_abspath, path_or_url, pool));
 
-      err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
-                                  pool);
+      err = svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE, pool);
 
       if ((err && err->apr_err == SVN_ERR_WC_PATH_NOT_FOUND)
           || kind == svn_node_unknown || kind == svn_node_none)
@@ -1179,8 +1177,7 @@ svn_client_proplist3(const char *path_or
 
       SVN_ERR(svn_dirent_get_absolute(&local_abspath, path_or_url, pool));
 
-      err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
-                                  pool);
+      err = svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE, pool);
 
       if ((err && err->apr_err == SVN_ERR_WC_PATH_NOT_FOUND)
           || kind == svn_node_unknown || kind == svn_node_none)

Modified: subversion/trunk/subversion/libsvn_client/repos_diff.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/repos_diff.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/repos_diff.c (original)
+++ subversion/trunk/subversion/libsvn_client/repos_diff.c Tue Apr 27 21:33:08 2010
@@ -346,7 +346,7 @@ get_dir_abspath(const char **local_dir_a
       svn_error_t *err;
       const char *local_abspath;
       SVN_ERR(svn_dirent_get_absolute(&local_abspath, path, pool));
-      err = svn_wc__node_get_kind(&kind, wc_ctx, local_abspath, FALSE, pool);
+      err = svn_wc_read_kind(&kind, wc_ctx, local_abspath, FALSE, pool);
       if (err)
         {
           if (lenient)

Modified: subversion/trunk/subversion/libsvn_client/status.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/status.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/status.c (original)
+++ subversion/trunk/subversion/libsvn_client/status.c Tue Apr 27 21:33:08 2010
@@ -267,8 +267,7 @@ svn_client_status5(svn_revnum_t *result_
     svn_node_kind_t kind, disk_kind;
 
     SVN_ERR(svn_io_check_path(target_abspath, &disk_kind, pool));
-    err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, target_abspath, FALSE,
-                                pool);
+    err = svn_wc_read_kind(&kind, ctx->wc_ctx, target_abspath, FALSE, pool);
 
     if (err && ((err->apr_err == SVN_ERR_WC_MISSING) ||
                 (err->apr_err == SVN_ERR_WC_NOT_WORKING_COPY)))
@@ -297,8 +296,8 @@ svn_client_status5(svn_revnum_t *result_
 
         if (kind != svn_node_file)
           {
-            err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, dir_abspath,
-                                        FALSE, pool);
+            err = svn_wc_read_kind(&kind, ctx->wc_ctx, dir_abspath, FALSE,
+                                   pool);
 
             svn_error_clear(err);
 

Modified: subversion/trunk/subversion/libsvn_client/switch.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/switch.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/switch.c (original)
+++ subversion/trunk/subversion/libsvn_client/switch.c Tue Apr 27 21:33:08 2010
@@ -153,8 +153,8 @@ switch_internal(svn_revnum_t *result_rev
           return SVN_NO_ERROR;
         }
 
-      SVN_ERR(svn_wc__node_get_kind(&target_kind, ctx->wc_ctx,
-                                    local_abspath, TRUE, pool));
+      SVN_ERR(svn_wc_read_kind(&target_kind, ctx->wc_ctx, local_abspath, TRUE,
+                               pool));
 
       if (target_kind == svn_node_dir)
         SVN_ERR(svn_wc_crop_tree2(ctx->wc_ctx, local_abspath, depth,

Modified: subversion/trunk/subversion/libsvn_client/update.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/update.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_client/update.c (original)
+++ subversion/trunk/subversion/libsvn_client/update.c Tue Apr 27 21:33:08 2010
@@ -169,8 +169,8 @@ update_internal(svn_revnum_t *result_rev
           return SVN_NO_ERROR;
         }
 
-      SVN_ERR(svn_wc__node_get_kind(&target_kind, ctx->wc_ctx,
-                                    local_abspath, TRUE, pool));
+      SVN_ERR(svn_wc_read_kind(&target_kind, ctx->wc_ctx, local_abspath, TRUE,
+                               pool));
       if (target_kind == svn_node_dir)
         {
           SVN_ERR(svn_wc_crop_tree2(ctx->wc_ctx, local_abspath, depth,

Modified: subversion/trunk/subversion/libsvn_wc/node.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/node.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/node.c (original)
+++ subversion/trunk/subversion/libsvn_wc/node.c Tue Apr 27 21:33:08 2010
@@ -169,11 +169,11 @@ svn_wc__node_get_repos_info(const char *
 }
 
 svn_error_t *
-svn_wc__node_get_kind(svn_node_kind_t *kind,
-                      svn_wc_context_t *wc_ctx,
-                      const char *abspath,
-                      svn_boolean_t show_hidden,
-                      apr_pool_t *scratch_pool)
+svn_wc_read_kind(svn_node_kind_t *kind,
+                 svn_wc_context_t *wc_ctx,
+                 const char *abspath,
+                 svn_boolean_t show_hidden,
+                 apr_pool_t *scratch_pool)
 {
   svn_wc__db_kind_t db_kind;
   svn_error_t *err;

Modified: subversion/trunk/subversion/libsvn_wc/status.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/status.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/status.c (original)
+++ subversion/trunk/subversion/libsvn_wc/status.c Tue Apr 27 21:33:08 2010
@@ -2291,7 +2291,7 @@ svn_wc_walk_status(svn_wc_context_t *wc_
       ignore_patterns = ignores;
     }
 
-  SVN_ERR(svn_wc__node_get_kind(&kind, wc_ctx, local_abspath, FALSE, scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&kind, wc_ctx, local_abspath, FALSE, scratch_pool));
   SVN_ERR(svn_io_check_path(local_abspath, &local_kind, scratch_pool));
 
   if (kind == svn_node_file && local_kind == svn_node_file)

Modified: subversion/trunk/subversion/svn/main.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/main.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/main.c (original)
+++ subversion/trunk/subversion/svn/main.c Tue Apr 27 21:33:08 2010
@@ -1997,8 +1997,8 @@ main(int argc, const char *argv[])
 
           if (!err)
             {
-              err = svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath,
-                                          FALSE, pool);
+              err = svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
+                                     pool);
 
               if (!err && kind != svn_node_none && kind != svn_node_unknown)
                 {

Modified: subversion/trunk/subversion/svn/propedit-cmd.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/svn/propedit-cmd.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================
--- subversion/trunk/subversion/svn/propedit-cmd.c (original)
+++ subversion/trunk/subversion/svn/propedit-cmd.c Tue Apr 27 21:33:08 2010
@@ -229,8 +229,8 @@ svn_cl__propedit(apr_getopt_t *os,
               /* Split the path if it is a file path. */
               SVN_ERR(svn_dirent_get_absolute(&local_abspath, target, subpool));
 
-              SVN_ERR(svn_wc__node_get_kind(&kind, ctx->wc_ctx, local_abspath,
-                                            FALSE, subpool));
+              SVN_ERR(svn_wc_read_kind(&kind, ctx->wc_ctx, local_abspath, FALSE,
+                                       subpool));
 
               if (kind == svn_node_none)
                 return svn_error_createf(
--- subversion/trunk/subversion/libsvn_client/patch.c (original)
+++ subversion/trunk/subversion/libsvn_client/patch.c Tue Apr 27 21:33:08 2010
@@ -290,8 +290,8 @@ resolve_target_path(patch_target_t *targ
       return SVN_NO_ERROR;
     }
 
-  SVN_ERR(svn_wc__node_get_kind(&target->kind, wc_ctx, target->abs_path,
-                                FALSE, scratch_pool));
+  SVN_ERR(svn_wc_read_kind(&target->kind, wc_ctx, target->abs_path, FALSE,
+                           scratch_pool));
   switch (target->kind)
     {
       case svn_node_file:
@@ -307,8 +307,8 @@ resolve_target_path(patch_target_t *targ
            * create it. Check if the containing directory of the target
            * exists. We may need to create it later. */
           abs_dirname = svn_dirent_dirname(target->abs_path, scratch_pool);
-          SVN_ERR(svn_wc__node_get_kind(&kind, wc_ctx, abs_dirname,
-                                        FALSE, scratch_pool));
+          SVN_ERR(svn_wc_read_kind(&kind, wc_ctx, abs_dirname, FALSE,
+                                   scratch_pool));
           SVN_ERR(svn_wc_status3(&status, wc_ctx, abs_dirname,
                                  scratch_pool, scratch_pool));
           target->parent_dir_exists =
@@ -1341,9 +1341,8 @@ install_patched_target(patch_target_t *t
                                         const char *);
               abs_path = svn_dirent_join(abs_path, component, pool);
 
-              SVN_ERR(svn_wc__node_get_kind(&kind, ctx->wc_ctx,
-                                            abs_path, TRUE,
-                                            iterpool));
+              SVN_ERR(svn_wc_read_kind(&kind, ctx->wc_ctx, abs_path, TRUE,
+                                       iterpool));
               if (kind == svn_node_file)
                 {
                   /* Obstructed. */
@@ -1355,7 +1354,7 @@ install_patched_target(patch_target_t *t
                   /* ### wc-ng should eventually be able to replace
                    * directories in-place, so this schedule conflict
                    * check will go away. We could then also make the
                    * svn_wc__node_get_kind() call above ignore hidden
                    * nodes.*/
                   svn_boolean_t is_deleted;
 
@@ -1355,7 +1354,7 @@ install_patched_target(patch_target_t *t
                    * directories in-place, so this schedule conflict
                    * check will go away. We could then also make the
-                   * svn_wc__node_get_kind() call above ignore hidden
+                   * svn_wc_read_kind() call above ignore hidden
                    * nodes.*/
                   svn_boolean_t is_deleted;

Modified: subversion/trunk/subversion/libsvn_client/prop_commands.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/prop_commands.c?rev=938674&r1=938673&r2=938674&view=diff
==============================================================================